@@ -1,7 +1,7 @@
 /* ===EmacsMode: -*- Mode: C; tab-width:4; c-basic-offset: 4; -*- === */
 /* ===FileName: ===
    Copyright (c) 1998 Takuya SHIOZAKI, All Rights reserved.
-   Copyright (c) 1998 X-TrueType Server Project, All rights reserved. 
+   Copyright (c) 1998 X-TrueType Server Project, All rights reserved.
    Copyright (c) 2003 After X-TT Project, All rights reserved.
 
 ===Notice
@@ -30,7 +30,6 @@
 
 Notice===
  */
-/* $XFree86: xc/lib/font/FreeType/xttcap.c,v 1.1 2003/10/19 18:53:50 dawes Exp $ */
 
 /*
 #include "xttversion.h"
@@ -134,7 +133,7 @@ get_record_type_by_name(SPropertyRecord const ** const refRefRecord, /*result*/
 {
     Bool result = False;
     int i;
-    
+
     *refRefRecord = NULL;
     for (i=0; i<numOfValidRecords; i++) {
         if (!strcasecmp(validRecords[i].strRecordName, strName)) {
@@ -143,7 +142,7 @@ get_record_type_by_name(SPropertyRecord const ** const refRefRecord, /*result*/
             break;
         }
     }
-    
+
     return result;
 }
 
@@ -162,7 +161,7 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
             {
                 int val;
                 char *endPtr;
-                    
+
                 val = strtol(strValue, &endPtr, 0);
                 if ('\0' != *endPtr) {
                     fprintf(stderr,
@@ -179,7 +178,7 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
             {
                 double val;
                 char *endPtr;
-                    
+
                 val = strtod(strValue, &endPtr);
                 if ('\0' != *endPtr) {
                     fprintf(stderr,
@@ -195,7 +194,7 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
         case eRecTypeBool:
             {
                 Bool val;
-                
+
                 if (!strcasecmp(strValue, "yes"))
                     val = True;
                 else if (!strcasecmp(strValue, "y"))
@@ -234,15 +233,14 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
         case eRecTypeString:
             {
                 char *p;
-                    
-                if (NULL == (p = malloc(strlen(strValue)+1))) {
+
+                if (NULL == (p = strdup(strValue))) {
                     fprintf(stderr,
                             "truetype font property : "
                             "cannot allocate memory.\n");
                     result = True;
                     goto quit;
                 }
-                strcpy(p, strValue);
                 SPropContainer_value_str(&tmpContainerE) = p;
             }
             break;
@@ -258,7 +256,7 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
         {
             /* add to list */
             SPropRecValListNodeP *newNode;
-            
+
             if (NULL == (newNode = malloc(sizeof(*newNode)))) {
                 fprintf(stderr,
                         "truetype font property : "
@@ -302,11 +300,11 @@ get_one_line(FILE *is, char *buf)
     Bool flInDoubleQuote = False;
     Bool flBackSlash = False;
     Bool flFirstElement = True;
-    
+
     *buf = '\0';
     for (;;) {
         int c = fgetc(is);
-        
+
         if (ferror(is)) {
             fprintf(stderr, "truetype font property file : read error.\n");
             result = True;
@@ -447,7 +445,7 @@ parse_one_line(SDynPropRecValList *pThisList, FILE *is)
     Bool result = False;
     char *buf = NULL;
     char *recordHead, *valueHead = NULL;
-    
+
     if (NULL == (buf = malloc(LEN_LINEBUF))) {
         fprintf(stderr,
                 "truetype font property file : cannot allocate memory.\n");
@@ -484,7 +482,7 @@ parse_one_line(SDynPropRecValList *pThisList, FILE *is)
     }
   quit:
     free(buf);
-  abort:    
+  abort:
     return result;
 }
 
@@ -495,7 +493,7 @@ SPropRecValList_read_prop_file(SDynPropRecValList *pThisList,
 {
     Bool result = False;
     FILE *is;
-    
+
 #if 1
     if (!strcmp(strFileName, "-"))
         is = stdin;
@@ -531,7 +529,7 @@ Bool /* True == Error, False == Success */
 SPropRecValList_new(SDynPropRecValList *pThisList)
 {
     Bool result = False;
-    
+
     pThisList->headNode = NULL;
 
     return result;
@@ -583,7 +581,7 @@ SPropRecValList_search_record(SRefPropRecValList *pThisList,
 {
     Bool result = False;
     SPropRecValListNodeP *p;
-    
+
     *refRecValue = NULL;
     for (p=pThisList->headNode; NULL!=p; p=p->nextNode) {
         if (!strcasecmp(p->containerE.refRecordType->strRecordName,
@@ -606,7 +604,7 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
     Bool result = False;
     /*    SPropertyRecord const *refRecordType; */
     char const *term;
-    
+
     if (NULL == (term = strrchr(strCapHead, ':')))
         goto abort;
 
@@ -647,7 +645,7 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
             char *duplicated = malloc((nextColon-strCapHead)+1);
             {
                 char *value;
-            
+
                 memcpy(duplicated, strCapHead, nextColon-strCapHead);
                 duplicated[nextColon-strCapHead] = '\0';
                 if (NULL != (value=strchr(duplicated, '='))) {
@@ -655,7 +653,7 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
                     value++;
                 } else
                     value = &duplicated[nextColon-strCapHead];
-            
+
                 for (i=0; i<numOfCorrespondRelations; i++) {
                     if (!strcasecmp(correspondRelations[i].capVariable,
                                       duplicated)) {
@@ -677,30 +675,10 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
         }
         strCapHead = nextColon+1;
     }
-    
+
     /*  quit: */
   abort:
     return result;
 }
 
-
-/**************************************************************************
-  Functions (xttmisc)
- */
-
-/* strdup clone with using the allocator of X server */
-char *
-XttXstrdup(char const *str)
-{
-    char *result;
-    
-    result = malloc(strlen(str)+1);
-
-    if (result)
-        strcpy(result, str);
-
-    return result;
-}
-
-
 /* end of file */
